@@ -80,6 +80,9 @@ class Updater:
             print('update now..')
             
             self.run_update(remote_meta)
+            
+        with open(fname, 'wb') as f:
+                pickle.dump(remote_meta, f)
     
     def run_update(self, meta, distfold = './'):
         res = requests.get(meta.last_version_url, stream=True)
