@@ -1,4 +1,6 @@
 import json
+import os
+from tqdm import tqdm
 
 from pydantic import BaseModel
 from google.cloud import storage
@@ -26,7 +28,8 @@ class AppArchiver:
             text = blob.download_as_text()
             meta = Meta.parse_obj(json.loads(text))
         except NotFound as e:
-            self.meta = Meta.parse_obj({})
+            meta = Meta.parse_obj({})
+            self.meta = meta
             self.upload_meta()
             
         self.meta = meta
@@ -35,17 +38,25 @@ class AppArchiver:
     
     def upload_meta(self):
         blob = self.bucket.blob(f'{self.app_name}/meta.json')
-        blob.upload_from_string(json.dumps(self.meta.dict()))
+        
+        metastr = json.dumps(self.meta.dict())
+        print(f'updating meta {metastr}')
+        
+        blob.upload_from_string(metastr)
         blob.make_public()
         
     
     def upload_archive(self, filename: str, version: str):
+        CHUNK_SIZE = 262144
         
-        blob = self.bucket.blob(f'{self.app_name}/app_v{version}.zip')
+        blob = self.bucket.blob(f'{self.app_name}/app_v{version}.zip', chunk_size=CHUNK_SIZE)
         with open(filename, 'rb') as f:
-            blob.upload_from_file(f)
+            total_bytes = os.fstat(f.fileno()).st_size
+            with tqdm.wrapattr(f, "read", total=total_bytes, miniters=1, desc=f"upload to {filename}") as file_obj:
+                blob.upload_from_file(file_obj)
         
         blob.make_public()
+        self.meta.current_version = version
         self.meta.last_version_url = blob.public_url
         self.upload_meta()
         
@@ -68,6 +79,6 @@ if __name__ == '__main__':
     
     app = AppArchiver('automap')
     app.get_meta()
-    app.upload_archive('test_blues.zip', '1.3.0')
+    app.upload_archive('test/assets/test_loc.zip', '2.5.0')
     
     
\ No newline at end of file
